@@ -104,14 +104,8 @@ def deduplicate(
             ),
         )
         if partition_pruning_params["oldest_target_partition"] is None:
-            LOGGER(
-                "There is no data: - {project_id}.{source_dataset}.{source_table} - between [{start_date} - {end_date}] .".format(
-                    project_id=project_id,
-                    source_dataset=source_dataset,
-                    source_table=source_table,
-                    start_date=buffered_start_date,
-                    end_date=end_date,
-                )
+            LOGGER.info(
+                f"There is no data: - {project_id}.{source_dataset}.{source_table} - between [{start_date} - {end_date}] ."
             )
             return None
         additional_merge_conditions = get_deduplication_additional_merge_conditions(
