@@ -1,5 +1,5 @@
+from airflow_commons.logger import LOGGER
 from airflow_commons.utils.mysql.mysql_utils import upsert, get_db_engine
-import airflow_commons.logger as logger
 from airflow_commons.utils.file_utils import read_sql
 from airflow_commons.utils.mysql.sql_utils import get_delete_sql
 from airflow_commons.utils.mysql.sql_utils import get_select_all_sql
@@ -28,14 +28,14 @@ def write_to_mysql(
     """
     engine = get_db_engine(username, password, host, db_name)
     chunks = [values[i : i + chunk_size] for i in range(0, len(values), chunk_size)]
-    logger.LOGGER("Chunk size is {}.".format(chunk_size))
+    LOGGER.info(f"Chunk size is {chunk_size}.")
     with engine.connect() as conn:
         i = 0
         for chunk in chunks:
             i += 1
             upsert(values=chunk, conn=conn, table_name=table_name)
-            logger.LOGGER("Chunk {} uploaded".format(i))
-    logger.LOGGER("Data uploaded to MySql.")
+            LOGGER.info(f"Chunk {i} uploaded")
+    LOGGER.info("Data uploaded to MySql.")
 
 
 def delete(
@@ -71,7 +71,7 @@ def delete(
     cursor.execute(sql)
     connection.commit()
     connection.close()
-    logger.LOGGER("The below sql statement is executed " + sql)
+    LOGGER.info(f"The below sql statement is executed \n {sql}")
 
 
 def select_all(
@@ -109,8 +109,8 @@ def select_all(
     result = cursor.fetchall()
     connection.commit()
     connection.close()
-    logger.LOGGER("The below sql statement is executed \n" + sql)
-    logger.LOGGER("Number of records retrieved = " + str(len(result)))
+    LOGGER.info(f"The below sql statement is executed \n {sql}")
+    LOGGER.info(f"Number of records retrieved = {str(len(result))}")
     return result
 
 
@@ -140,11 +140,11 @@ def get_row_count(
         where_statement=where_statement,
     )
 
-    logger.LOGGER("The below sql statement will be executed: \n" + sql)
+    LOGGER.info(f"The below sql statement will be executed: \n {sql}")
     cursor = connection.cursor()
     cursor.execute(sql)
     row_count = cursor.fetchone()[0]
     connection.commit()
     connection.close()
-    logger.LOGGER("The sql statement is executed successfully\n")
+    LOGGER.info("The sql statement is executed successfully\n")
     return row_count
