@@ -25,16 +25,16 @@ def upload_file_to_s3_bucket(path_to_file: str, bucket_name: str, file_name: str
     :param bucket_name: Name of the bucket that file will be uploaded to.
     :param file_name: Name of the file (key of the file in s3).
     """
-    LOGGER("Upload to " + bucket_name + " started")
+    LOGGER.info("Upload to {bucket_name} started")
     upload_start = datetime.now()
     s3_client = boto3.client("s3")
     try:
         s3_client.upload_file(path_to_file, bucket_name, file_name)
     except S3UploadFailedError as e:
-        LOGGER("Upload to " + bucket_name + " failed")
+        LOGGER.error(f"Upload to {bucket_name} failed")
         raise e
     upload_end = datetime.now()
-    LOGGER(
+    LOGGER.info(
         "Upload finished in {duration} seconds".format(
             duration=round((upload_end - upload_start).total_seconds())
         )
@@ -61,7 +61,7 @@ def write_into_s3_file(
     :param retry_count: retry count for S3 upload equals to three on default
     """
 
-    LOGGER("Writing to " + bucket_name + "/" + file_name + " started")
+    LOGGER.info(f"Writing to {bucket_name}/{file_name} started")
     writing_start = datetime.now()
     total_upload_tries = 0
     while total_upload_tries <= retry_count:
@@ -76,15 +76,14 @@ def write_into_s3_file(
             except botocore.exceptions.NoCredentialsError as e:
                 total_upload_tries = total_upload_tries + 1
                 if total_upload_tries == retry_count:
+                    LOGGER.error(
+                        f"Writing into {bucket_name}/{file_name} failed, message {e}"
+                    )
                     raise e
                 time.sleep(1)
     writing_end = datetime.now()
-    LOGGER(
-        (
-            "Writing finished in ",
-            round((writing_end - writing_start).total_seconds()),
-            " seconds",
-        )
+    LOGGER.info(
+        f"Writing finished in {round((writing_end - writing_start).total_seconds())} seconds"
     )
 
 
@@ -119,7 +118,7 @@ def read_from_s3_file(
     :return: content of the target file in string format
     """
 
-    LOGGER("Reading from " + bucket_name + "/" + file_name + " started")
+    LOGGER.info(f"Reading from {bucket_name}/{file_name} started")
     reading_start = datetime.now()
     total_read_tries = 0
     while total_read_tries <= retry_count:
@@ -134,15 +133,14 @@ def read_from_s3_file(
             except botocore.exceptions.NoCredentialsError as e:
                 total_read_tries = total_read_tries + 1
                 if total_read_tries == retry_count:
+                    LOGGER.error(
+                        f"Reading from {bucket_name}/{file_name} failed, message {e}"
+                    )
                     raise e
                 time.sleep(1)
     reading_end = datetime.now()
-    LOGGER(
-        (
-            "Reading finished in ",
-            round((reading_end - reading_start).total_seconds()),
-            " seconds",
-        )
+    LOGGER.info(
+        f"Reading finished in {round((reading_end - reading_start).total_seconds())} seconds"
     )
     return data.decode("utf-8")
 
@@ -166,7 +164,7 @@ def move_s3_file(
     :param retry_count: retry count for S3 moving equals to three on default
     """
 
-    LOGGER("Moving from " + source_path + " to " + destination_path + " started")
+    LOGGER.info(f"Moving from {source_path} to {destination_path} started")
     moving_start = datetime.now()
     total_move_tries = 0
     while total_move_tries <= retry_count:
@@ -180,13 +178,12 @@ def move_s3_file(
         except botocore.exceptions.NoCredentialsError as e:
             total_move_tries = total_move_tries + 1
             if total_move_tries == retry_count:
+                LOGGER.error(
+                    f"Reading from {source_path} to {destination_path} failed, message {e}"
+                )
                 raise e
             time.sleep(1)
     moving_end = datetime.now()
-    LOGGER(
-        (
-            "Moving finished in ",
-            round((moving_end - moving_start).total_seconds()),
-            " seconds",
-        )
+    LOGGER.info(
+        f"Moving finished in {round((moving_end - moving_start).total_seconds())} seconds"
     )
